.. -- Dependencies ------------------------------

.. |astropy| replace:: `astropy`
.. _astropy: http://www.astropy.org/

.. |dateutil| replace:: `dateutil`
.. _dateutil: https://dateutil.readthedocs.io

.. |dqsegdb2| replace:: `dqsegdb2`
.. _dqsegdb2: https://dqsegdb2.readthedocs.io

.. |gwdatafind| replace:: `gwdatafind`
.. _gwdatafind: https://gwdatafind.readthedocs.io

.. |gwosc-mod| replace:: `gwosc`
.. _gwosc-mod: https://gwosc.readthedocs.io

.. |h5py| replace:: `h5py`
.. _h5py: http://docs.h5py.org/en/latest/

.. |ligo-segments| replace:: `ligo-segments`
.. _ligo-segments: https://lscsoft.docs.ligo.org/ligo-segments/

.. |ligotimegps| replace:: `ligotimegps`
.. _ligotimegps: https://github.com/gwpy/ligotimegps/

.. |matplotlib| replace:: `matplotlib`
.. _matplotlib: https://matplotlib.org/

.. |numpy| replace:: `numpy`
.. _numpy: http://numpy.org/

.. |scipy| replace:: `scipy`
.. _scipy: http://www.scipy.org/

.. |six| replace:: `six`
.. _six: https://six.readthedocs.io/

.. |tqdm| replace:: `tqdm`
.. _tqdm: https://github.com/tqdm/tqdm

.. -- Extra software ----------------------------

.. |framel| replace:: `framel`
.. _framel: http://lappweb.in2p3.fr/virgo/FrameL/

.. |LDAStools.frameCPP| replace:: `LDAStools.frameCPP`
.. _LDAStools.frameCPP: https://ldas-jobs.ligo.caltech.edu/~emaros/share/doc/ldas-tools/framecpp/html/

.. |lal| replace:: `lal`
.. _lal: http://software.ligo.org/docs/lalsuite/lal/

.. |lal.LIGOTimeGPS| replace:: `lal.LIGOTimeGPS`
.. _lal.LIGOTimeGPS: http://software.ligo.org/docs/lalsuite/lal/struct_l_i_g_o_time_g_p_s.html

.. |lalframe| replace:: `lalframe`
.. _lalframe: http://software.ligo.org/docs/lalsuite/lalframe/

.. |MySQLdb| replace:: `MySQLdb`
.. _MySQLdb: http://mysql-python.sourceforge.net/

.. |nds2| replace:: `nds2`
.. _nds2: https://www.lsc-group.phys.uwm.edu/daswg/projects/nds-client/doc/manual/

.. |numpydoc| replace:: `numpydoc`
.. _numpydoc: https://numpydoc.readthedocs.io/

.. |python-ligo-lw| replace:: `python-ligo-lw`
.. _python-ligo-lw: https://git.ligo.org/kipp.cannon/python-ligo-lw

.. |pycbc| replace:: `pycbc`
.. _pycbc: https://pycbc.org/

.. |root_numpy| replace:: `root_numpy`
.. _root_numpy: https://rootpy.github.io/root_numpy/

.. |sphinx| replace:: `sphinx`
.. _sphinx: http://www.sphinx-doc.org/

.. |sphinx-bootstrap-theme| replace:: `sphinx-bootstrap-theme`
.. _sphinx-bootstrap-theme: http://sphinx-bootstrap-theme.readthedocs.io/

.. |sphinxcontrib-programoutput| replace:: `sphinx-programoutput`
.. _sphinxcontrib-programoutput: https://pythonhosted.org/sphinxcontrib-programoutput/

.. |sphinx-automodapi| replace:: `sphinx-automodapi`
.. _sphinx-automodapi: http://sphinx-automodapi.readthedocs.io/

.. -- Other references --------------------------

.. |GWOSC| replace:: The Gravitational-Wave Open Science Centre (GWOSC)
.. _GWOSC: https://www.gw-openscience.org/

.. |LIGO-T050017| replace:: LIGO-T050017
.. _LIGO-T050017: https://dcc.ligo.org/LIGO-T050017/public
